stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -d fruinfo
ipmcset -t main -d ac
ipmcget -d version
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.78.41
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.78.41 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d sel -v list
ipmcget -d version
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
ipmcget -d led
echo $?
/dev/shm/busybox_x telnet 70.189.78.41
whoami
ipmcget -d fruinfo
/dev/shm/busybox_x telnet 70.189.78.41
whoami
mdbctl
ipmcget -d diaginfo
ls -ltr /tmp
 ls /tmp/dump_info.tar.gz
 rm -rf /tmp/dump_info.tar.gz
bye
whoami
ipmcget -d powerstate
lspci -vvv -s 06:00.0
ipmcset -t sol -d activate -v 2 0
ipmcget -t sensor -d list | grep "PCIe3 Card BBU"
while : ;do ipmcget -d time; ipmcget -t sensor -d list | grep "PCIe3 Card BBU";sleep 1;done;
while : ;do ipmcget -d time; ipmcget -t sensor -d list | grep "PCIe3 Card BBU";done;
ipmcset -t main -d ac
while : ;do ipmcget -d time; ipmcget -t sensor -d list | grep "PCIe3 Card BBU";done;
mdbctl
ipmcset -t main -d ac
mdbctl
ipmcget -d fru
msbctl
mdbctl
busctl --user call bmc.kepler.hwproxy /bmc/kepler/Chip/Eeprom/Eeprom_NIC_010107 bmc.kepler.Chip.BlockIO Read a{ss}uu 0 0x0 256
ipmcset -t sol -d activate -v 2 0
busctl --user list |grep network_adapter
systemctl restart hardware
systemctl restart hardware.service
ipmcget -d reset
ipmcset -d reset
mdbctl
ipmcget -d v
cat /etc/package_info |grep sensor
ipmcset -t sol -d activate -v 2 0
mdbctl
ipmcset -t main -d ac
mdbctl
ipmcset -t main -d ac
mdbctl
ipmcget -d v
ipmcget -t sensor -d list | grep DISK
ipmcset -t main -d ac
ipmcget -t sensor -d list | grep DISK
ipmcset -t main -d ac
ipmcget -t sensor -d list | grep DISK
ipmcget -d v
